# Compressed Databases
Authors: **Ahmed M Moustafa and Paul J Planet**

## Rules

Each Compressed Database Release has more genomes analyzed from GISAID, new STs and CCs may be assigned and older CCs may be renamed.


GISAID Sequences inclusion criteria in this analysis.
  - Complete, high coverage genomes (excluding low coverage ) were downloaded from GISAID.
  - Genomes had at least 29,000 bp in length and had less than 1% Ns.
  - Any genome that had any ambiguity (any letter other than A,T,G and C) in the 10 open reading frames (ORF) was excluded.

The STs identified by GNUVID were grouped into larger taxonomic units, clonal complexes (CCs), defined as clusters of >20 STs that were single or double allele variants (SLV or DLV) away from a “founder” as defined in a a minimum spanning tree (MST) using the goeBURST algorithm.

## Limitations

- Because a change in any allele creates a new ST our method may accumulate and count “unnecessary” STs that have been seen only once or may be due to a sequencing error. This is partially ameliorated by the use of the CC definition that allows some variability amongst the members of a group. A large number of STs also may allow more granular approaches to tracking new lineages.

- The status of the CCs (active, silent and inactive) may be a sampling issue.

- Certain regions (US and Europe) clearly sequenced more genomes compared to other regions.

**The table below shows summary information of the 177 Active Clonal Complexes (CCs).**

The "Most common 5 countries" and "Most common Region" columns show the five countries and the region, respectively, with the most sequences from each Clonal Complex. Starting from the DB update (06/21/2021), the GISAID clades are reported for each CC for easier correlation between the two systems. **A full report for the 2888 CCs can be found [here](https://github.com/ahmedmagds/GNUVID/blob/master/db/GNUVID_06212021_CCs_report.txt)**.


| Clonal Complex | Number of STs/isolates | Most common 5 countries | Most common Region | Date range | Status | Pango Lineage (%isolates) | GISAID Clade (%) | WHO Naming | AA Substitutions in >=60% of isolates |
|----------------|-------------------------|-------------------------|--------------------|------------|--------|---------------------------|------------------|------------|---------------------------------------|
| **255** | 4542/8068 | USA (23%), United Kingdom (11%), India (6%), Denmark (5%), Turkey (5%) | Europe (56%) | 2020-01-24 to 2021-06-08 | **Active** | B.1 (62%) | G (97%) | NA | Spike_D614G (99%),NSP12_P323L (97%) |
| **26377** | 2842/5128 | United Kingdom (36%), Denmark (26%), Spain (16%), Netherlands (4%), Sweden (3%) | Europe (99%) | 2020-03-02 to 2021-06-08 | **Active** | B.1.177 (35%) | GV (100%) | NA | Spike_D614G (100%),NSP12_P323L (100%),N_A220V (100%),Spike_A222V (100%) |
| **26754** | 2656/4401 | United Kingdom (23%), Spain (15%), Iceland (11%), Italy (9%), Switzerland (9%) | Europe (99%) | 2020-04-30 to 2021-06-08 | **Active** | B.1.177 (61%) | GV (99%) | NA | NSP12_P323L (100%),N_A220V (100%),Spike_D614G (100%),Spike_A222V (100%) |
| **29259** | 838/1409 | United Kingdom (30%), Netherlands (24%), Italy (15%), Switzerland (8%), Spain (5%) | Europe (100%) | 2020-03-10 to 2021-06-08 | **Active** | B.1.177 (86%) | GV (100%) | NA | NSP12_P323L (100%),Spike_A222V (100%),Spike_D614G (100%),N_A220V (100%),Spike_P272L (100%),Spike_A262S (98%) |
| **30018** | 1357/2679 | Denmark (49%), United Kingdom (9%), Sweden (8%), Germany (8%), Czech Republic (6%) | Europe (100%) | 2020-07-31 to 2021-06-08 | **Active** | B.1.258 (61%) | G (100%) | NA | NSP13_H290Y (100%),NSP9_M101I (100%),Spike_D614G (100%),NSP12_P323L (100%),NSP3_I1683T (100%),NSP13_A598S (100%),NSP12_V720I (100%),Spike_H69del (100%),Spike_V70del (100%),Spike_N439K (100%) |
| **31179** | 4444/8355 | United Kingdom (88%), Germany (2%), Spain (2%), Netherlands (2%), Denmark (1%) | Europe (100%) | 2020-03-14 to 2021-06-08 | **Active** | B.1.177 (94%) | GV (100%) | NA | Spike_D614G (100%),N_A220V (100%),Spike_A222V (100%),NSP12_P323L (100%),Spike_L18F (90%) |
| **45062** | 37369/78812 | United Kingdom (51%), Germany (6%), USA (5%), Japan (5%), Sweden (4%) | Europe (89%) | 2020-09-20 to 2021-06-13 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_D614G (100%),Spike_N501Y (100%),N_S235F (100%),Spike_A570D (100%),Spike_S982A (100%),Spike_T716I (100%),NSP12_P323L (100%),NSP3_T183I (100%),Spike_V70del (100%),NSP3_A890D (100%),Spike_P681H (100%),N_R203K (100%),Spike_D1118H (100%),N_D3L (100%),Spike_H69del (100%),NS8_Q27stop (100%),NS8_R52I (100%),N_G204R (100%),Spike_Y144del (100%),NSP3_I1412T (100%),NS8_Y73C (100%),NSP6_G107del (99%),NSP6_F108del (99%),NSP6_S106del (99%) |
| **49676** | 1095/3120 | United Kingdom (80%), Germany (6%), Sweden (3%), USA (2%), Switzerland (2%) | Europe (97%) | 2020-10-11 to 2021-06-14 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),Spike_P681H (100%),Spike_D1118H (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_H69del (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP3_A890D (100%),NSP6_F108del (100%),Spike_S982A (100%),N_S235F (100%),NSP3_I1412T (100%),NS8_R52I (100%),N_D3L (100%),N_G204R (100%),Spike_Y144del (99%),NSP2_L550F (90%) |
| **57630** | 5274/10748 | United Kingdom (57%), USA (20%), Ireland (5%), Germany (5%), Norway (4%) | Europe (78%) | 2020-10-29 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_D1118H (100%),Spike_D614G (100%),NS3_L15F (100%),Spike_N501Y (100%),NSP3_A890D (100%),N_S235F (100%),NSP3_T183I (100%),Spike_P681H (100%),Spike_A570D (100%),NSP3_I1412T (100%),NS8_Q27stop (100%),NSP13_K460R (100%),Spike_S982A (100%),Spike_T716I (100%),Spike_V70del (100%),NSP12_P323L (100%),N_D3L (100%),Spike_H69del (100%),N_R203K (100%),NS8_Y73C (100%),N_G204R (100%),NS8_R52I (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),Spike_Y144del (100%),NSP4_F17L (99%) |
| **57685** | 240/552 | United Kingdom (79%), Norway (10%), USA (3%), Switzerland (2%), Ireland (1%) | Europe (96%) | 2020-10-29 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NSP3_T183I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_Y144del (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),N_S235F (100%),Spike_H69del (100%),Spike_T716I (100%),Spike_A570D (100%),NS8_R52I (100%),Spike_P681H (100%),NSP3_A890D (100%),NS8_Y73C (100%),Spike_V70del (100%),Spike_S982A (100%),NS8_Q27stop (100%),NSP13_K460R (98%),NSP4_F17L (96%) |
| **58534** | 16403/32114 | United Kingdom (28%), USA (25%), Sweden (8%), Germany (7%), Canada (6%) | Europe (68%) | 2020-10-31 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_D614G (100%),NS8_Y73C (100%),Spike_D1118H (100%),NS8_R52I (100%),Spike_T716I (100%),NS8_Q27stop (100%),Spike_N501Y (100%),Spike_P681H (100%),NSP3_A890D (100%),NSP12_P323L (100%),Spike_A570D (100%),Spike_S982A (100%),NSP3_T183I (100%),NS8_K68stop (100%),Spike_V70del (100%),Spike_H69del (100%),N_S235F (100%),N_D3L (100%),NSP3_I1412T (100%),N_R203K (100%),Spike_Y144del (100%),NSP6_G107del (99%),NSP6_S106del (99%),NSP6_F108del (99%),N_G204R (97%) |
| **62415** | 1227/2507 | USA (38%), United Kingdom (30%), Belgium (7%), Switzerland (5%), Sweden (4%) | Europe (61%) | 2020-11-06 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_T716I (100%),Spike_A570D (100%),Spike_P681H (100%),M_V70L (100%),NS8_Y73C (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NSP3_A890D (100%),Spike_D614G (100%),Spike_S982A (100%),NS8_R52I (100%),Spike_V70del (100%),Spike_H69del (100%),N_R203K (100%),NSP13_K460R (100%),Spike_D1118H (100%),NSP12_P323L (100%),Spike_Y144del (100%),N_D3L (100%),N_G204R (99%),N_S235F (99%),NSP6_S106del (98%),NSP6_G107del (98%),NSP6_F108del (98%) |
| **66369** | 754/1464 | United Kingdom (49%), Sweden (13%), Poland (8%), Germany (6%), Italy (5%) | Europe (96%) | 2020-11-13 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | NS8_Q27stop (100%),Spike_N501Y (100%),NS8_R52I (100%),Spike_P681H (100%),M_A2S (100%),NS8_Y73C (100%),NSP12_P323L (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),NSP3_I1412T (100%),Spike_D1118H (100%),N_G204R (100%),Spike_V70del (100%),Spike_D614G (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP3_A890D (100%),NSP6_F108del (100%),Spike_Y144del (99%),Spike_H69del (98%) |
| **67441** | 3272/6185 | Netherlands (58%), United Kingdom (35%), Denmark (2%), France (1%), Belgium (1%) | Europe (99%) | 2020-11-14 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),Spike_T716I (100%),NS8_R52I (100%),N_S235F (100%),NSP6_G107del (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),N_D3L (100%),Spike_S982A (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP6_F108del (100%),Spike_D614G (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP12_P323L (100%),Spike_H69del (100%),NSP3_A890D (100%),Spike_V70del (100%),NSP3_T183I (100%),NS8_K68stop (100%),NSP3_I1412T (100%),NSP2_N280Y (100%),NS8_L118V (87%) |
| **69093** | 167/299 | United Kingdom (48%), USA (19%), Pakistan (8%), Germany (5%), Denmark (4%) | Europe (66%) | 2020-11-18 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),NS3_R68S (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_H69del (100%),NS8_Q27stop (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_D1118H (100%),Spike_V70del (100%),NSP12_P323L (99%) |
| **72462** | 231/303 | USA (81%), Mexico (13%), Canada (5%), Aruba (2%) | North America (98%) | 2020-06-18 to 2021-06-07 | **Active** | B.1.561 (100%) | G (99%) | NA | NS3_I62T (100%),NSP12_P323L (100%),NSP5_K90R (100%),Spike_D614G (100%),N_M234I (100%),N_S194L (100%),NSP2_V571L (100%),NSP3_I1094V (100%),Spike_D138Y (99%) |
| **73310** | 327/612 | Belgium (58%), United Kingdom (32%), Germany (4%), France (2%), Switzerland (2%) | Europe (100%) | 2020-11-08 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP3_G307C (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),N_G204R (100%),Spike_D614G (100%),Spike_S982A (100%),N_S235F (100%),NSP3_A1179V (100%),NSP3_A890D (100%),NS8_Y73C (100%),NSP12_P323L (100%),Spike_P681H (100%),Spike_H69del (100%),Spike_V70del (100%),N_D3L (99%),Spike_Y144del (97%) |
| **73877** | 234/281 | France (32%), USA (10%), Mayotte (8%), South Africa (6%), Turkey (5%) | Europe (60%) | 2020-10-30 to 2021-06-08 | **Active** | B.1.351.2 (53%) | GH (98%) | Beta | E_P71L (100%),N_T205I (100%),NS3_Q57H (100%),NSP2_T85I (100%),Spike_D614G (100%),NS3_S171L (100%),Spike_K417N (100%),NSP5_K90R (100%),NSP12_P323L (99%),Spike_A701V (99%),NSP3_K837N (99%),Spike_D80A (99%),Spike_D215G (98%),Spike_N501Y (97%),NSP6_S106del (97%),NSP6_G107del (97%),NSP6_F108del (97%),Spike_L242del (96%),Spike_E484K (95%),Spike_L244del (95%),Spike_A243del (95%),Spike_L18F (75%),NSP3_N1778S (63%) |
| **75324** | 508/1031 | Germany (34%), United Kingdom (29%), Spain (23%), Belgium (4%), Switzerland (2%) | Europe (100%) | 2020-12-09 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_T716I (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_D1118H (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),NSP3_T183I (100%),N_R203K (100%),Spike_A570D (100%),N_G204R (100%),Spike_H69del (100%),NSP6_S106del (100%),NSP2_L550F (100%),NSP6_G107del (100%),NSP3_A890D (100%),NSP6_F108del (100%),NS8_Q27stop (100%),Spike_D138H (100%),NS8_Y73C (100%),NS8_R52I (100%),Spike_Y144del (99%),N_S235F (99%) |
| **75478** | 732/1322 | France (35%), United Kingdom (29%), Italy (6%), Netherlands (5%), Switzerland (5%) | Europe (94%) | 2020-12-05 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_T716I (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),Spike_V70del (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_H69del (100%),N_R203K (100%),Spike_P681H (100%),NSP3_T183I (100%),Spike_Y144del (100%),NSP12_P323L (100%),NS8_Q27stop (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),N_G204R (100%),Spike_S98F (100%) |
| **75998** | 1233/2713 | United Kingdom (62%), Germany (11%), Spain (5%), Italy (5%), Switzerland (4%) | Europe (96%) | 2020-12-10 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_A570D (100%),Spike_N501Y (100%),Spike_D614G (100%),Spike_H69del (100%),NSP3_T183I (100%),Spike_V70del (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_T716I (100%),NSP3_A890D (100%),NS8_Y73C (100%),N_R203K (100%),NSP3_I1412T (100%),Spike_P681H (100%),N_G204R (100%),NS8_Q27stop (100%),Spike_Y144del (100%),NSP12_P323L (100%),NSP6_S106del (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_R52I (100%) |
| **76487** | 60/152 | United Kingdom (76%), Ireland (11%), Switzerland (4%), Peru (2%), Portugal (1%) | Europe (97%) | 2020-12-06 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_S982A (100%),N_S235F (100%),NSP3_T183I (99%),N_D3L (99%),NSP2_L550F (87%) |
| **78217** | 541/1164 | USA (68%), United Kingdom (12%), Germany (6%), France (4%), Poland (1%) | North America (69%) | 2020-12-15 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),N_R203K (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_S982A (100%),N_S235F (100%),Spike_A570D (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),N_D3L (100%),NSP12_P227L (84%),NSP14_P451S (80%) |
| **78279** | 1165/1654 | USA (29%), United Kingdom (15%), France (12%), Germany (6%), Spain (6%) | Europe (57%) | 2020-12-15 to 2021-06-08 | **Active** | B.1.525 (100%) | G (100%) | Eta | NSP12_P323F (100%),Spike_D614G (100%),Spike_H69del (100%),M_I82T (100%),Spike_A67V (100%),N_A12G (100%),Spike_Q677H (100%),Spike_E484K (100%),Spike_V70del (100%),Spike_Y144del (100%),Spike_F888L (100%),NSP3_T1189I (100%),NSP6_G107del (100%),NSP6_S106del (100%),NSP6_F108del (100%),N_T205I (99%),Spike_Q52R (98%),E_L21F (96%) |
| **78362** | 96/202 | United Kingdom (76%), Poland (13%), Denmark (2%), Lithuania (2%), Ireland (1%) | Europe (100%) | 2020-12-15 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),Spike_V622F (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),NSP2_D286Y (99%),N_G204R (98%) |
| **78510** | 746/1438 | United Kingdom (27%), Poland (18%), Germany (17%), Denmark (15%), Switzerland (9%) | Europe (100%) | 2020-12-12 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NS8_Q27stop (100%),N_R203K (100%),Spike_N501Y (100%),NS8_R52I (100%),NSP3_A890D (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP3_T183I (100%),NSP3_I1412T (100%),NS8_Y73C (100%),Spike_H69del (100%),Spike_T716I (100%),Spike_P681H (100%),Spike_D1118H (100%),Spike_V70del (100%),Spike_A570D (100%),Spike_Y144del (100%),NSP6_S106del (97%),NSP6_G107del (97%),NSP6_F108del (97%) |
| **78964** | 478/1891 | United Kingdom (100%), USA (0%), Sweden (0%), Switzerland (0%), Germany (0%) | Europe (100%) | 2020-12-17 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS3_G100C (99%) |
| **79365** | 321/935 | United Kingdom (95%), Spain (1%), Italy (1%), Germany (1%), Sweden (1%) | Europe (100%) | 2020-12-15 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS8_Q27stop (100%),NS8_Y73C (100%),NS8_R52I (100%),Spike_Q677H (100%),NSP3_H295Y (94%) |
| **80811** | 2652/6156 | Denmark (44%), France (13%), Germany (10%), Sweden (10%), USA (8%) | Europe (88%) | 2020-11-30 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),N_R203K (100%),Spike_D614G (100%),NSP3_T183I (100%),Spike_T716I (100%),Spike_P681H (100%),Spike_S982A (100%),N_S235F (100%),Spike_N501Y (100%),NSP3_A890D (100%),NSP12_P323L (100%),Spike_A570D (100%),NS3_W131C (100%),NSP3_I1412T (100%),N_G204R (100%),Spike_D1118H (100%),N_D3L (100%),Spike_H69del (100%),Spike_V70del (100%),NS8_Y73C (100%),NS8_R52I (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),Spike_Y144del (99%),NS8_K68stop (99%) |
| **81085** | 4671/6354 | Brazil (57%), USA (24%), Spain (3%), Italy (3%), Chile (2%) | South America (63%) | 2020-10-01 to 2021-06-09 | **Active** | P.1 (95%) | GR (99%) | Gamma | NSP3_K977Q (100%),Spike_D614G (100%),Spike_N501Y (100%),Spike_H655Y (100%),Spike_E484K (100%),Spike_T20N (100%),NS8_E92K (100%),Spike_L18F (100%),Spike_P26S (100%),NSP13_E341D (100%),N_P80R (100%),NSP3_S370L (100%),NSP12_P323L (100%),NS3_S253P (99%),Spike_V1176F (99%),Spike_T1027I (99%),N_R203K (99%),N_G204R (99%),Spike_R190S (99%),NSP6_S106del (99%),NSP6_G107del (99%),NSP6_F108del (99%),Spike_D138Y (97%),Spike_K417T (97%) |
| **102721** | 106/136 | USA (99%), Ghana (1%), Mexico (1%) | North America (99%) | 2020-10-19 to 2021-06-09 | **Active** | B.1.2 (100%) | GH (100%) | NA | NSP16_R216C (100%),NS3_Q57H (100%),NSP5_L89F (100%),NS8_S24L (100%),NSP14_N129D (100%),NS3_G172V (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP2_T85I (99%),N_P199L (99%),N_P67S (99%),NSP2_T634I (95%),NSP3_T771I (94%),NSP13_K467R (94%) |
| **111217** | 8418/16766 | Germany (40%), Denmark (15%), Sweden (9%), Czech Republic (7%), Switzerland (4%) | Europe (99%) | 2020-11-23 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),Spike_A570D (100%),NSP3_A890D (100%),Spike_D614G (100%),N_S235F (100%),NSP3_T183I (100%),NSP12_P323L (100%),Spike_P681H (100%),Spike_D1118H (100%),Spike_N501Y (100%),Spike_S982A (100%),NSP3_I1412T (100%),Spike_T716I (100%),NS8_R52I (100%),N_D3L (100%),N_G204P (100%),NS8_Y73C (100%),Spike_V70del (100%),Spike_H69del (100%),Spike_Y144del (99%),NSP6_G107del (99%),NSP6_F108del (99%),NSP6_S106del (99%),NS8_K68stop (99%),N_R203K (97%) |
| **119929** | 491/740 | USA (98%), Mexico (1%), Canada (0%), Australia (0%), Japan (0%) | North America (99%) | 2020-11-18 to 2021-06-09 | **Active** | B.1.427/429 (56%) | GH (100%) | Alert | NS3_Q57H (100%),NSP9_I65V (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_W152C (100%),Spike_S13I (100%),NSP2_T85I (100%),Spike_L452R (100%),NS8_V100L (100%),N_T205I (100%),NSP13_D260Y (100%),N_M234I (100%) |
| **125706** | 87/248 | United Kingdom (82%), Germany (9%), USA (2%), Italy (2%), Poland (1%) | Europe (97%) | 2020-12-19 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),N_P142S (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_R203K (100%),N_G204R (100%),N_S235F (100%),NSP16_D220N (78%),NSP3_L1287P (78%) |
| **125785** | 84/180 | USA (46%), United Kingdom (44%), Spain (4%), Portugal (2%), Luxembourg (2%) | Europe (53%) | 2020-12-19 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NS3_V202L (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_H69del (99%),NS8_Q27stop (99%),NS8_R52I (99%),N_G204R (99%),Spike_V70del (99%),NSP8_Q24R (61%),NSP13_K460R (61%) |
| **129667** | 894/1621 | Switzerland (28%), USA (27%), Germany (14%), United Kingdom (5%), Sweden (5%) | Europe (71%) | 2020-12-15 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_N501Y (100%),NS8_R52I (100%),Spike_D1118H (100%),NS8_Y73C (100%),Spike_V70del (100%),Spike_H69del (100%),Spike_A570D (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_T716I (100%),NSP3_A890D (100%),N_R203K (100%),N_G204R (100%),Spike_S982A (100%),N_S235F (100%),Spike_Y144del (100%),Spike_S94F (95%),NSP9_P83L (95%),NSP3_R1518K (95%) |
| **130333** | 1909/2978 | Israel (77%), Belgium (9%), USA (4%), United Kingdom (3%), Germany (3%) | Asia (78%) | 2020-12-23 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),Spike_N501Y (100%),Spike_V70del (100%),NS3_T151I (100%),Spike_D614G (100%),Spike_S982A (100%),N_S235F (100%),Spike_T716I (100%),Spike_A570D (100%),Spike_P681H (100%),NSP3_A890D (100%),NSP12_P323L (100%),NSP3_T183I (100%),N_R203K (100%),NSP3_I1412T (100%),Spike_D1118H (100%),N_D3L (100%),Spike_L5F (100%),N_G204R (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),NS8_Q27stop (100%),NS8_Y73C (100%),NS8_R52I (100%),Spike_Y144del (100%),NS7a_Q62stop (98%) |
| **135283** | 2929/5174 | USA (99%), Mexico (0%), Costa Rica (0%), United Kingdom (0%), Colombia (0%) | North America (100%) | 2020-04-01 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),NSP6_S106del (100%),NS8_C61F (100%),NSP6_G107del (100%),NSP6_F108del (100%),NSP3_T183I (100%),Spike_P681H (100%),NS8_Y73C (100%),Spike_A570D (100%),NSP3_I1412T (100%),Spike_Y144del (100%),Spike_D1118H (100%),N_S235F (100%),Spike_H69del (100%),Spike_T716I (100%),Spike_N501Y (100%),NS8_R52I (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_R203K (100%),NSP3_A890D (100%),N_G204R (100%),Spike_S982A (100%),NSP12_P227L (100%),N_D3L (100%),NSP3_M1441I (99%),NS8_K68stop (99%) |
| **137051** | 209/436 | USA (88%), United Kingdom (3%), Canada (2%), Sweden (2%), Nigeria (1%) | North America (90%) | 2020-12-28 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NS8_Q27stop (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),Spike_H69del (100%),NSP3_T183I (100%),NS8_K68stop (100%),NSP3_A890D (100%),Spike_V70del (100%),N_S235F (100%),NSP3_I1412T (100%),NSP12_P227L (94%),NSP3_M1441I (82%) |
| **142413** | 134/222 | Spain (50%), United Kingdom (14%), Portugal (14%), Switzerland (12%), France (6%) | Europe (100%) | 2020-12-10 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | NSP3_T183I (100%),Spike_T716I (100%),Spike_A570D (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS8_Q27stop (100%),N_R203K (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_H69del (99%),NSP6_S106del (99%),Spike_Y144del (99%),NSP6_G107del (99%),NSP6_F108del (99%),Spike_V70del (99%),NS8_K68stop (95%) |
| **146594** | 293/1015 | United Kingdom (98%), Romania (0%), Germany (0%), Spain (0%), USA (0%) | Europe (100%) | 2020-12-31 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),NSP6_S106del (100%),NS7a_Q62stop (100%),NSP6_G107del (100%),NSP6_F108del (100%),N_S235F (100%),Spike_Y144del (100%),NSP2_L550F (71%) |
| **154031** | 98/256 | Spain (77%), United Kingdom (9%), Netherlands (6%), Germany (2%), Switzerland (2%) | Europe (100%) | 2021-01-07 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS7a_S81L (100%),NSP13_K460R (92%),NSP13_P78S (89%) |
| **154144** | 389/686 | USA (99%), Aruba (0%), Argentina (0%), United Kingdom (0%) | North America (99%) | 2021-01-07 to 2021-06-07 | **Active** | B.1.526 (100%) | GH (100%) | Iota | NS3_A33S (100%),Spike_T95I (100%),NS3_P42L (100%),Spike_L5F (100%),NSP2_T85I (100%),NSP12_P323L (100%),Spike_D614G (100%),N_P199L (100%),Spike_D253G (100%),N_M234I (100%),Spike_E484K (100%),NS8_T11I (100%),NSP4_L438P (100%),NSP4_S218F (100%),NSP6_G107del (100%),NSP6_S106del (100%),NSP6_F108del (100%),NS3_Q57H (100%),NSP13_Q88H (99%),Spike_A701V (99%) |
| **162283** | 351/619 | United Kingdom (21%), USA (17%), Germany (11%), Netherlands (10%), France (9%) | Europe (69%) | 2021-01-12 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_S982A (100%),NS8_Q27stop (100%),NS8_R52I (100%),Spike_Y144del (100%),Spike_T716I (100%),N_S235F (100%),NSP6_S106del (99%),N_R203K (99%),NSP6_G107del (99%),NSP6_F108del (99%),N_D3L (99%),N_G204R (99%),NSP3_T183I (98%),NS8_K68stop (97%) |
| **162300** | 78/245 | United Kingdom (99%), Lithuania (0%), France (0%) | Europe (100%) | 2021-01-12 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_S37P (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_Y144del (100%),N_G204R (100%),NSP6_V179I (99%) |
| **163774** | 332/416 | USA (60%), Chile (9%), Mexico (7%), Peru (5%), Argentina (5%) | North America (67%) | 2020-12-22 to 2021-06-07 | **Active** | C.37 (99%) | GR (100%) | Lambda | N_R203K (100%),NSP4_T492I (100%),NSP5_G15S (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452Q (100%),NSP6_S106del (100%),Spike_F490S (100%),NSP4_L438P (100%),N_G214C (100%),NSP6_G107del (100%),Spike_T859N (100%),N_P13L (99%),NSP3_F1569V (99%),NSP3_T428I (99%),NSP3_P1469S (99%),Spike_L249del (99%),Spike_S247del (99%),Spike_Y248del (99%),Spike_D253N (99%),Spike_R246del (99%),Spike_G252del (99%),Spike_T250del (99%),Spike_P251del (99%),NSP6_F108del (96%),Spike_T76I (92%),Spike_G75V (91%),N_T366I (65%) |
| **166576** | 88/277 | United Kingdom (94%), USA (6%) | Europe (94%) | 2020-12-13 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),Spike_Y660F (100%),N_S235F (100%),NSP14_P140S (71%) |
| **167072** | 289/485 | USA (44%), France (28%), Denmark (8%), Sweden (5%), United Kingdom (4%) | Europe (55%) | 2020-12-10 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP6_S106del (100%),Spike_A570D (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_S235F (100%),NSP3_T183I (100%),Spike_T716I (100%),Spike_P681R (100%),N_G204R (100%),N_D3L (100%),Spike_S982A (100%),N_R203K (100%),NSP8_Q24R (99%),NSP3_T749A (99%),NSP3_A1502V (93%),NSP1_R24C (93%) |
| **170898** | 83/153 | USA (47%), Germany (20%), United Kingdom (13%), Belgium (5%), Denmark (4%) | North America (52%) | 2020-12-29 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),NS3_H78Y (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),N_G204R (95%),NSP12_P227L (83%),NSP3_A41V (81%),NSP3_M1441I (81%) |
| **171625** | 71/105 | Germany (36%), United Kingdom (30%), USA (28%), Japan (2%), Netherlands (1%) | Europe (70%) | 2020-11-12 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (96%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_Y144del (100%),Spike_S221L (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),NS8_R52I (99%),N_S235F (99%) |
| **171815** | 108/216 | Belgium (75%), Luxembourg (17%), United Kingdom (5%), France (3%), Switzerland (0%) | Europe (100%) | 2021-01-16 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),NSP13_A52V (100%),N_R203K (100%),Spike_A570D (100%),NSP13_K460R (100%),NS3_P262S (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),M_V70L (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NS7a_P45L (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),N_P279Q (100%),Spike_Y144del (99%) |
| **173566** | 1009/1897 | USA (95%), United Kingdom (4%), Canada (1%), Netherlands (0%), Germany (0%) | North America (95%) | 2020-12-05 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NSP6_S106del (100%),NS3_P240S (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP6_F108del (100%),NS8_Q27stop (100%),Spike_T716I (100%),NSP3_I1412T (100%),NSP3_A890D (100%),Spike_D1118H (100%),Spike_D614G (100%),N_S235F (100%),Spike_H69del (100%),Spike_A570D (100%),NS8_R52I (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_S982A (100%),N_R203K (100%),Spike_N501Y (100%),N_G204R (100%),NSP3_T183I (100%),Spike_Y144del (100%),N_D3L (100%),NS8_K68stop (98%),NSP12_P227L (95%),NSP3_E95D (95%),NSP3_M1441I (95%) |
| **174091** | 263/800 | United Kingdom (100%) | Europe (100%) | 2021-01-18 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NS7a_G70C (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **174872** | 98/149 | France (77%), Lithuania (6%), Luxembourg (5%), United Kingdom (5%), Switzerland (3%) | Europe (99%) | 2020-12-13 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_P151L (100%),N_S235F (100%),Spike_H69del (99%),NSP6_S106del (99%),NS7a_A105T (99%),NSP6_G107del (99%),NSP6_F108del (99%),Spike_V70del (99%),Spike_Y144del (99%) |
| **175144** | 233/516 | USA (99%), Croatia (1%) | North America (99%) | 2021-01-14 to 2021-06-07 | **Active** | B.1.526 (98%) | GH (100%) | Iota | Spike_T95I (100%),N_M234I (100%),NS3_P42L (100%),NSP6_G107del (100%),NSP6_S106del (100%),Spike_E484K (100%),NSP6_F108del (100%),NSP13_Q88H (100%),Spike_L5F (100%),NS8_T11I (100%),NSP2_T85I (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_L438P (100%),Spike_D253G (100%),Spike_A701V (100%),N_P199L (100%),NS3_Q57H (99%) |
| **176133** | 55/91 | France (32%), Germany (26%), United Kingdom (16%), Switzerland (12%), Romania (4%) | Europe (99%) | 2021-01-03 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),Spike_A570D (100%),Spike_N501Y (100%),N_A173V (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),N_R203K (99%),N_G204R (98%) |
| **176141** | 335/586 | France (34%), United Kingdom (33%), Sweden (15%), Switzerland (5%), USA (3%) | Europe (96%) | 2020-12-31 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_T716I (100%),Spike_H69del (100%),Spike_V70del (100%),Spike_Y144del (99%) |
| **177422** | 254/791 | Denmark (63%), United Kingdom (32%), Switzerland (1%), Germany (1%), France (1%) | Europe (100%) | 2020-11-13 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_N501Y (100%),Spike_Y144del (100%),NS8_T87I (100%),NSP12_D736G (63%) |
| **182216** | 26/70 | United Kingdom (67%), Poland (17%), Germany (9%), USA (4%), Italy (1%) | Europe (96%) | 2021-01-21 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NS3_A23S (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **184259** | 67/103 | Germany (31%), Spain (21%), Poland (9%), Lithuania (8%), Belgium (6%) | Europe (96%) | 2021-01-22 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_S982A (100%),N_S235F (100%),NS8_Q27stop (99%),NS8_R52I (99%),Spike_P681H (99%),Spike_Y144del (99%),NSP3_A890D (99%),N_G204P (99%),N_D3L (99%) |
| **190327** | 99/246 | United Kingdom (94%), Spain (2%), USA (1%), Belgium (1%), India (0%) | Europe (98%) | 2021-01-09 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (87%) | Alpha | NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_D1118H (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS8_Q27stop (100%),NS8_R52I (100%),NS8_Y73C (100%),NSP3_I1412T (99%),Spike_H69del (98%),NSP6_S106del (98%),Spike_Y144del (98%),NSP6_G107del (98%),NSP6_F108del (98%),Spike_V70del (98%) |
| **195602** | 89/287 | United Kingdom (100%) | Europe (100%) | 2021-01-27 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_V355I (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS7a_K117I (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP6_V179I (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **196197** | 567/1521 | Norway (99%), Germany (0%), Denmark (0%), Slovenia (0%), Sweden (0%) | Europe (100%) | 2021-01-27 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS3_P42H (100%),NS8_Y73C (100%),Spike_V70del (100%),Spike_D614G (100%),Spike_S982A (100%),NSP6_S106del (100%),N_R203K (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP6_F108del (100%),N_G204R (100%),N_D3L (100%),NSP12_P323L (100%),N_S235F (100%),NSP13_K460R (100%),NSP13_P78S (100%) |
| **197851** | 3200/5761 | USA (98%), United Kingdom (2%), Aruba (0%), Canada (0%), Italy (0%) | North America (98%) | 2020-11-13 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NSP3_T183I (100%),Spike_K1191N (100%),Spike_D1118H (100%),Spike_D614G (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_S982A (100%),Spike_H69del (100%),Spike_A570D (100%),Spike_T716I (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_Y144del (100%),Spike_V70del (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),NSP12_P323L (100%),N_S235F (100%),NS8_Q27stop (100%),N_R203K (100%),N_D3L (100%),NS8_R52I (100%),N_G204R (100%),NS8_Y73C (100%),NSP13_K460R (99%),NSP8_Q24R (98%),NSP16_K160R (98%) |
| **204799** | 187/328 | Belgium (83%), Netherlands (5%), United Kingdom (5%), France (4%), Turkey (3%) | Europe (100%) | 2021-01-29 to 2021-06-10 | **Active** | P.1 (98%) | GR (99%) | Gamma | NSP6_S106del (100%),Spike_H655Y (100%),Spike_T1027I (100%),Spike_N501Y (100%),Spike_L18F (100%),N_P80R (100%),NSP6_G107del (100%),NSP6_F108del (100%),NS8_E92K (100%),NSP12_P323L (100%),Spike_D614G (100%),NS3_I118M (100%),NSP13_E341D (100%),Spike_E484K (100%),Spike_K417T (100%),NS3_S253P (100%),NSP3_K977Q (100%),NSP3_S370L (100%),Spike_V1176F (100%),N_R203K (99%),N_G204R (99%),Spike_T20N (99%),Spike_P26S (99%),Spike_D138Y (99%),Spike_R190S (98%) |
| **209187** | 771/1030 | USA (85%), Spain (9%), Bonaire (2%), Dominican Republic (1%), Belgium (1%) | North America (87%) | 2020-12-02 to 2021-06-09 | **Active** | B.1.575 (100%) | GH (100%) | NA | M_I82T (100%),N_T205I (100%),NSP12_P323L (100%),Spike_D614G (100%),NS3_Q57H (100%),NSP6_T181I (100%),NSP2_T85I (100%),Spike_T716I (100%),Spike_P681H (100%),NSP13_P47S (100%),Spike_S494P (100%),NSP4_T492I (100%),NSP3_S1406F (96%) |
| **209663** | 54/246 | United Kingdom (100%) | Europe (100%) | 2021-02-02 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),Spike_G261R (100%),NSP3_A488T (100%),NSP2_L550F (100%),NSP3_R1912H (100%),NSP6_G107del (100%),NSP3_A890D (100%),NS8_A65V (100%),NSP13_P504S (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP4_S34F (74%) |
| **212159** | 81/94 | Russia (76%), Finland (5%), Germany (5%), Switzerland (4%), Turkey (3%) | Europe (100%) | 2021-02-02 to 2021-06-08 | **Active** | B.1.1.523 (99%) | GR (97%) | NA | NSP2_N269D (100%),N_R203K (100%),Spike_R158del (100%),Spike_E156del (100%),Spike_F157del (100%),NSP12_S229N (100%),M_I82T (100%),NSP13_P77L (100%),N_G204R (100%),NSP12_P323L (100%),Spike_T1027I (99%),NSP6_V84F (99%),Spike_D839V (99%),Spike_F306L (99%),Spike_S494P (98%),Spike_E484K (98%),NSP10_T111I (98%),N_G212C (98%),NSP3_R1297I (98%),Spike_D614G (98%),NS3_S171L (98%),NSP5_V303I (97%),Spike_E780A (96%),NS3_V201F (94%),NSP3_M84V (89%),NSP13_L455M (79%) |
| **219216** | 28/97 | United Kingdom (100%) | Europe (100%) | 2021-02-06 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),NSP8_T187I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP12_L280S (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP2_T103I (66%) |
| **219864** | 149/202 | Philippines (42%), Japan (18%), USA (13%), United Kingdom (5%), Australia (5%) | Asia (69%) | 2021-02-06 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_Y144del (100%),NS7a_S37F (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS3_T12I (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS8_R52I (100%),NS8_K68stop (96%),N_G204R (95%) |
| **219948** | 410/599 | USA (37%), United Kingdom (24%), France (5%), Germany (5%), Belgium (4%) | Europe (52%) | 2021-01-07 to 2021-06-08 | **Active** | B.1.1.318 (99%) | GR (99%) | Alert | Spike_E484K (100%),N_R203K (100%),NSP3_K1693N (100%),NS8_E106stop (100%),NSP4_T173I (100%),M_I82T (100%),NSP4_A446V (100%),N_G204R (100%),Spike_T95I (100%),NSP6_S106del (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP6_F108del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_Y144del (99%),Spike_D796H (99%),NSP5_T21I (99%),N_R209del (99%),N_A208G (99%),NS8_F3Y (98%),NSP15_V320M (98%),NSP3_E378V (87%) |
| **220457** | 162/533 | United Kingdom (100%) | Europe (100%) | 2021-02-07 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP3_S1206L (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_Y144del (100%) |
| **225274** | 53/166 | Denmark (50%), United Kingdom (45%), Germany (2%), USA (2%), Poland (1%) | Europe (98%) | 2020-11-21 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),NS7a_L17F (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_T716I (99%),NSP8_Q24R (70%),NSP13_K460R (70%) |
| **225509** | 28/77 | United Kingdom (100%) | Europe (100%) | 2021-02-09 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_M740V (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),N_S235L (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%) |
| **235241** | 279/530 | USA (99%), France (0%), Costa Rica (0%), Poland (0%) | North America (99%) | 2021-01-04 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NS3_A33S (100%),NS8_Q27stop (100%),NSP3_T183I (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_H69del (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),N_G204R (100%),Spike_V70del (100%),NS8_K68stop (99%),NSP6_L260F (99%),NSP3_A1527V (99%),Spike_T716I (99%) |
| **235245** | 126/243 | USA (98%), South Korea (2%) | North America (98%) | 2021-02-12 to 2021-06-11 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_N616S (100%),NS8_Q27stop (100%),NSP3_T183I (100%),NSP8_T145I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP12_P227L (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),N_S235F (100%),Spike_H69del (100%),Spike_T716I (100%),NSP3_A890D (100%),Spike_V70del (100%),Spike_S982A (100%),NS8_K68stop (98%) |
| **235389** | 70/176 | Denmark (66%), Poland (15%), Germany (7%), Switzerland (5%), Sweden (3%) | Europe (100%) | 2021-02-12 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_A890V (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (99%) |
| **240052** | 109/390 | United Kingdom (100%) | Europe (100%) | 2021-01-04 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_D627G (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP2_L550F (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_V667I (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **241513** | 728/1478 | USA (37%), United Kingdom (25%), Netherlands (8%), Denmark (7%), Germany (6%) | Europe (57%) | 2021-01-04 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | NS8_Q27stop (100%),N_R203K (100%),Spike_S98F (100%),N_N8D (100%),NSP2_L550F (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),Spike_D614G (100%),N_S235F (100%),NSP3_T183I (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),NSP12_P323L (100%),N_D3L (100%),Spike_S982A (100%),Spike_T716I (100%),Spike_V70del (100%),Spike_H69del (100%),Spike_A570D (100%),NS8_R52I (100%),NSP6_G107del (99%),NSP6_F108del (99%),NSP6_S106del (99%),Spike_D138H (98%),Spike_Y144del (98%) |
| **250854** | 54/99 | USA (90%), Sweden (8%), United Kingdom (2%) | North America (90%) | 2020-11-24 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (95%) | Alpha | Spike_H69del (100%),NSP3_T183I (100%),NS8_K68stop (100%),NSP6_S106del (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),N_S235F (100%),Spike_T716I (99%),N_R203K (99%),N_G204R (99%),Spike_S982A (98%),NS8_Q27stop (97%),Spike_D1118H (97%),NSP3_A1527V (90%),NSP2_I468L (89%),NSP3_T1056I (89%) |
| **251475** | 409/1170 | United Kingdom (87%), Spain (6%), Switzerland (2%), Germany (2%), Romania (1%) | Europe (98%) | 2020-12-15 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),Spike_T716I (100%),NSP6_S106del (100%),Spike_N501Y (100%),NS8_R52I (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP3_T183I (100%),N_R203K (100%),Spike_A570D (100%),NSP3_I1412T (100%),Spike_P681H (100%),N_G204R (100%),NSP3_T1306I (90%),NSP2_L448F (60%) |
| **254131** | 48/192 | United Kingdom (100%) | Europe (100%) | 2021-02-20 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NS7a_P84S (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),NS3_G224C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),NS3_V225F (100%),N_S235F (100%) |
| **254979** | 622/1471 | USA (100%), Mexico (0%) | North America (100%) | 2021-02-04 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),Spike_A570D (100%),Spike_N501Y (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_D178H (100%),M_V70L (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),NSP12_P323L (100%),Spike_D614G (100%),N_S235F (100%),Spike_T716I (100%),N_R203K (100%),N_G204R (100%),Spike_S982A (100%),NSP13_K460R (100%),NSP3_M768I (100%),N_D3L (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP16_D102N (100%),NSP6_F108del (100%),NSP3_I1412T (100%),Spike_Y144del (99%),Spike_H69del (99%),Spike_V70del (99%) |
| **255442** | 25/72 | United Kingdom (100%) | Europe (100%) | 2021-01-12 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NSP3_Q203R (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),Spike_S98F (100%),Spike_D138G (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **258101** | 2059/3717 | Netherlands (85%), Belgium (10%), Germany (4%), United Kingdom (1%), France (0%) | Europe (100%) | 2020-11-17 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NSP12_P323L (100%),Spike_D614G (100%),Spike_T716I (100%),NSP6_S106del (100%),Spike_N501Y (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_S235F (100%),Spike_H69del (100%),NS8_Q27stop (100%),N_R203K (100%),NSP3_I1412T (100%),Spike_V70del (100%),N_D3L (100%),Spike_S982A (100%),NSP3_T183I (100%),N_G204R (100%),Spike_A570D (100%),NS8_R52I (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_Y144del (100%) |
| **263429** | 167/547 | United Kingdom (100%), Norway (0%) | Europe (100%) | 2020-12-22 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),M_V10A (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP2_L550F (100%) |
| **270914** | 61/200 | United Kingdom (100%) | Europe (100%) | 2021-02-15 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_L5F (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),NS3_G224C (100%),N_G204R (100%),Spike_V70del (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),NS3_V225F (100%),N_S235F (100%),NSP12_P323L (100%),N_P13S (100%),NSP8_T89I (99%) |
| **272174** | 89/372 | United Kingdom (99%), Poland (1%) | Europe (100%) | 2021-02-27 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),E_R69G (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **275534** | 420/1036 | Germany (98%), Switzerland (2%), United Kingdom (0%), Luxembourg (0%), Italy (0%) | Europe (100%) | 2021-02-24 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP6_S106del (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_S98F (100%),NSP6_G107del (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),Spike_D614G (100%),N_S235F (100%),Spike_A570D (100%),NS3_L106F (100%),Spike_P681H (100%),NSP3_A890D (100%),N_G204P (100%),NSP12_P323L (100%),Spike_S982A (100%),NSP3_T183I (100%),Spike_T716I (100%),N_D3L (100%),Spike_Y144del (99%),NS8_K68stop (96%),N_R203K (92%),NSP2_E563D (78%) |
| **276177** | 50/195 | United Kingdom (100%) | Europe (100%) | 2021-03-01 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),N_P383S (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NS3_G100C (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **281056** | 50/64 | Germany (31%), Guadeloupe (25%), France (17%), Belgium (9%), USA (8%) | Europe (64%) | 2021-02-15 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),N_T379I (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP12_P227L (83%) |
| **281732** | 51/104 | Germany (33%), United Kingdom (25%), Norway (18%), Poland (15%), Belgium (5%) | Europe (100%) | 2021-01-02 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_Y144del (99%),NS3_V55F (77%) |
| **282476** | 183/293 | USA (99%), United Kingdom (1%) | North America (99%) | 2021-02-15 to 2021-06-07 | **Active** | B.1.526 (62%) | GH (100%) | Iota | NSP4_K399E (100%),NS3_P104F (100%),NSP6_S106del (100%),Spike_F157S (100%),Spike_Y144del (100%),N_M234I (100%),NS3_P42L (100%),NSP6_G107del (100%),N_T205I (100%),NSP6_F108del (100%),NS3_Q57H (100%),NS8_T11I (100%),NSP2_T85I (100%),NSP12_P323L (100%),Spike_D80G (100%),Spike_T859N (100%),NSP4_L438P (100%),NSP4_A446V (100%),NSP6_V278I (100%),Spike_D614G (100%),Spike_L452R (100%),NS8_A51S (99%),Spike_D950H (98%),NSP3_A861S (98%) |
| **282938** | 182/243 | USA (23%), Switzerland (19%), Germany (14%), United Kingdom (13%), France (7%) | Europe (71%) | 2021-01-31 to 2021-06-07 | **Active** | C.36.3 (88%) | GR (100%) | Alert | NSP4_D217N (100%),NSP4_D459N (100%),NS7b_A43S (100%),N_R203K (100%),Spike_S12F (100%),NSP6_L122S (100%),NSP1_E102K (100%),Spike_Q677H (100%),M_I82T (100%),NSP3_D821N (100%),NSP3_T428I (100%),N_G204R (100%),Spike_R346S (100%),Spike_A899S (100%),NSP12_P323L (100%),Spike_D614G (100%),N_G212V (100%),NSP13_D105Y (100%),Spike_W152R (100%),NSP3_A41V (100%),NSP6_S118L (100%),NSP5_G15S (99%),NSP3_P1469S (99%),Spike_L452R (99%),NSP8_T148I (99%),Spike_H69del (98%),Spike_V70del (98%) |
| **284694** | 182/289 | USA (100%) | North America (100%) | 2021-01-04 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),NS3_W131C (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),Spike_H69del (100%),Spike_N501Y (100%),Spike_Y144del (100%),Spike_V70del (100%),NSP12_P323L (100%),N_S235F (100%),NSP6_S106del (99%),NSP6_G107del (99%),NSP6_F108del (99%),NS8_K68stop (99%) |
| **285605** | 118/238 | USA (100%) | North America (100%) | 2021-03-03 to 2021-06-08 | **Active** | B.1.526 (74%) | GH (100%) | Iota | Spike_T95I (100%),NS7a_L116F (100%),NSP6_S106del (100%),Spike_L5F (100%),N_P13L (100%),NSP4_L438P (100%),Spike_D253G (100%),NSP3_G1128S (100%),Spike_S477N (100%),NS3_P42L (100%),NSP6_G107del (100%),N_S202R (100%),NSP6_F108del (100%),NS3_Q57H (100%),NS8_T11I (100%),NSP2_T85I (100%),Spike_D1260N (100%),Spike_A845S (100%),Spike_Q957R (100%),NSP2_K618N (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP13_Q88H (100%) |
| **286452** | 43/118 | United Kingdom (100%) | Europe (100%) | 2021-01-19 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP3_P153L (99%),NSP3_S692F (95%),Spike_S98F (95%) |
| **287449** | 282/418 | Greece (70%), Switzerland (9%), Austria (4%), United Kingdom (4%), France (3%) | Europe (99%) | 2021-02-05 to 2021-06-12 | **Active** | B.1.1.318 (100%) | GR (100%) | Alert | Spike_T95I (100%),NSP6_S106del (100%),N_R203K (100%),NSP3_K1693N (100%),NS8_E106stop (100%),Spike_D796H (100%),M_I82T (100%),NSP6_G107del (100%),NSP6_F108del (100%),NSP4_A446V (100%),N_G204R (100%),NSP15_V320M (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_E484K (99%),Spike_P681H (99%),Spike_Y144del (99%),NSP5_T21I (99%),NSP4_T173I (99%),N_R209del (99%),NS8_F3Y (99%),N_A208G (99%),NSP16_A116S (95%),N_M234I (95%),NSP3_E378V (93%),NSP3_D135N (72%) |
| **291132** | 139/333 | Switzerland (62%), Portugal (11%), United Kingdom (10%), France (5%), Sweden (5%) | Europe (98%) | 2021-01-12 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP3_A890D (100%),Spike_D1118H (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_H69del (100%),NSP3_I1412T (100%),Spike_V70del (100%),NS8_Q27stop (96%),NS8_R52I (96%),NS8_Y73C (96%),NSP6_S106del (96%),NSP6_G107del (96%),NSP6_F108del (96%),NSP3_A1305V (82%) |
| **292115** | 224/357 | United Kingdom (46%), India (21%), USA (16%), Australia (2%), Netherlands (2%) | Europe (55%) | 2021-03-05 to 2021-06-10 | **Active** | B.1.617.2 (99%) | G (100%) | Delta | N_R203M (100%),NS3_S26L (100%),Spike_P681R (100%),NSP3_P822L (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),N_D377Y (100%),M_I82T (100%),Spike_T19R (99%),N_D63G (98%),NSP4_D217N (98%),NSP2_P129L (98%),NSP4_F375S (98%),Spike_D950N (98%),NSP15_K259R (98%),NSP6_H11Q (98%),NS7a_V82A (94%),NS7a_T120I (94%),Spike_K77T (91%),Spike_R158del (80%),Spike_F157del (80%),Spike_E156G (80%),Spike_G142D (80%) |
| **301593** | 100/380 | United Kingdom (99%), Germany (1%), Chile (0%) | Europe (100%) | 2021-02-01 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NS6_T21I (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP13_K460R (99%),NSP14_E347G (99%),NSP3_I1460V (99%),NSP12_E744D (93%),Spike_V213M (93%),NSP3_G773E (93%),NSP1_S17I (92%),NSP15_C290Y (77%) |
| **301601** | 35/137 | United Kingdom (100%) | Europe (100%) | 2021-03-10 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP3_E1789K (100%),N_H145Q (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **302120** | 58/154 | United Kingdom (100%) | Europe (100%) | 2021-01-26 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **313129** | 942/2653 | Japan (99%), United Kingdom (0%), USA (0%), Poland (0%), Italy (0%) | Asia (99%) | 2021-03-03 to 2021-06-14 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),NSP3_I1412T (100%),NS8_R52I (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_N501Y (100%),Spike_P681H (100%),NSP12_P323L (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),Spike_V70del (100%),Spike_H69del (100%),Spike_Y144del (100%),NSP13_E261D (99%) |
| **315298** | 87/134 | Sweden (34%), Finland (18%), Japan (8%), United Kingdom (7%), Switzerland (7%) | Europe (79%) | 2021-01-22 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),Spike_A570D (100%),NS3_W131C (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_S982A (100%),N_R203K (99%),NS8_R52I (99%),N_G204R (99%),N_D3L (99%),N_S235F (99%),Spike_D614G (99%) |
| **317677** | 34/66 | USA (100%) | North America (100%) | 2021-02-26 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),Spike_A570D (100%),Spike_N501Y (100%),Spike_F79L (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_R203K (98%),N_G204R (98%),N_S235F (98%) |
| **321804** | 174/322 | United Kingdom (49%), Slovenia (14%), Lithuania (13%), Germany (11%), Netherlands (5%) | Europe (99%) | 2020-11-14 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),NSP6_S106del (100%),N_R203K (100%),NSP3_I1412T (100%),NS8_R52I (100%),N_T366I (100%),NSP6_G107del (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),N_S235F (100%),Spike_H69del (100%),Spike_T716I (100%),Spike_N501Y (100%),NSP3_A890D (100%),Spike_D1118H (100%),Spike_V70del (100%),Spike_S982A (100%),Spike_A570D (99%),Spike_P681H (99%),Spike_Y144del (99%) |
| **321903** | 27/44 | United Kingdom (73%), Ireland (18%), Switzerland (5%), Bulgaria (2%), Netherlands (2%) | Europe (100%) | 2021-01-25 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP2_L550F (73%) |
| **323594** | 201/736 | Japan (74%), United Kingdom (21%), Switzerland (1%), France (1%), Sweden (0%) | Asia (74%) | 2020-12-08 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_Y144del (100%),NSP12_P323L (99%),NSP2_F163L (73%) |
| **324539** | 438/842 | USA (83%), Mexico (11%), United Kingdom (2%), Brazil (1%), Switzerland (1%) | North America (94%) | 2021-02-24 to 2021-06-08 | **Active** | P.1 (99%) | GR (98%) | Gamma | Spike_H655Y (100%),Spike_L18F (100%),N_P80R (100%),Spike_T20N (100%),NSP3_K977Q (100%),NSP3_S370L (100%),Spike_P26S (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP13_E341D (100%),Spike_E484K (100%),Spike_T1027I (100%),Spike_N501Y (100%),NS3_S253P (100%),NSP6_S106del (100%),NSP6_G107del (100%),NSP6_F108del (100%),Spike_V1176F (100%),Spike_D138Y (99%),NS8_E92K (99%),Spike_R190S (99%),N_R203K (98%),N_G204R (98%),Spike_K417T (98%) |
| **325113** | 35/61 | Germany (82%), Belgium (11%), Spain (3%), Romania (2%), Luxembourg (2%) | Europe (100%) | 2021-02-16 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NS7a_S37F (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),N_S235F (100%),NSP8_Q24R (98%),Spike_S982A (98%),NSP3_H1307Y (90%) |
| **327701** | 57/164 | United Kingdom (79%), Spain (13%), Denmark (5%), Nigeria (1%), South Korea (1%) | Europe (98%) | 2021-01-28 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NS3_L106F (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **332387** | 55/139 | Japan (99%), Spain (1%), United Kingdom (1%) | Asia (99%) | 2021-02-22 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NS7a_Q62stop (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),N_R203K (99%),N_G204R (99%),N_P142S (99%) |
| **343533** | 37/53 | USA (96%), United Kingdom (4%) | North America (96%) | 2021-03-10 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),NSP13_R392C (100%),Spike_K1191N (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP8_Q24R (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP12_Q191R (100%),NSP2_A192T (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),Spike_D614G (100%),N_D3L (100%),NSP16_K160R (100%),Spike_S982A (100%),NSP3_G1476S (100%),N_S235F (100%),NSP12_P323L (96%),NSP13_A446S (85%) |
| **348191** | 126/229 | USA (91%), Mexico (6%), Italy (1%), Switzerland (1%), Germany (0%) | North America (97%) | 2021-03-24 to 2021-06-07 | **Active** | P.1 (99%) | GR (100%) | Gamma | NSP4_I23T (100%),NSP6_S106del (100%),Spike_H655Y (100%),N_R203K (100%),Spike_K417T (100%),NSP3_A1183T (100%),Spike_N501Y (100%),NS3_S253P (100%),N_P80R (100%),NSP1_T78A (100%),NSP3_K977Q (100%),NSP6_G107del (100%),NSP6_F108del (100%),N_D402Y (100%),NS8_E92K (100%),Spike_D614G (100%),N_S413I (100%),NSP13_E341D (100%),Spike_R190S (100%),Spike_E484K (100%),Spike_D138Y (100%),Spike_T1027I (99%),NSP3_S370L (99%),NSP12_P323L (99%),Spike_L18F (99%),Spike_T20N (99%),N_G204R (99%),Spike_P26S (99%),Spike_V1176F (99%) |
| **352824** | 124/148 | India (72%), Australia (10%), Belgium (3%), Italy (3%), Singapore (2%) | Asia (76%) | 2021-02-15 to 2021-06-07 | **Active** | B.1.617.1 (100%) | G (100%) | Kappa | N_R203M (100%),NSP15_K259R (100%),NS3_S26L (100%),Spike_D614G (100%),NS6_I33T (100%),Spike_L452R (100%),Spike_E484Q (99%),N_D377Y (99%),NSP13_M429I (99%),NSP3_T749I (99%),Spike_P681R (99%),NSP6_T77A (99%),NS7a_V82A (99%),NSP12_P323L (98%),NS8_S69L (93%),Spike_Q1071H (91%),Spike_E154K (89%),Spike_G142D (86%),Spike_H1101D (84%) |
| **353116** | 126/246 | Spain (39%), United Kingdom (38%), Portugal (8%), Germany (7%), USA (3%) | Europe (97%) | 2021-01-10 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (95%) | Alpha | NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NS3_T223I (100%),NS8_R52I (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_P681H (100%),NSP3_I1412T (98%),Spike_H69del (95%),NSP6_S106del (95%),Spike_Y144del (95%),NSP6_G107del (95%),NSP6_F108del (95%),Spike_V70del (95%) |
| **353755** | 92/132 | United Kingdom (43%), Italy (15%), Poland (11%), Spain (11%), Denmark (5%) | Europe (94%) | 2021-01-09 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),Spike_T95I (100%),NSP3_T183I (100%),Spike_T716I (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_S982A (100%),N_S235F (100%),NSP6_S106del (99%),NSP6_G107del (99%),NSP6_F108del (99%),N_D3L (99%) |
| **355862** | 37/66 | United Kingdom (35%), Finland (24%), Germany (17%), Estonia (11%), Lithuania (6%) | Europe (100%) | 2021-01-30 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP3_I1412T (97%),NSP14_A371V (67%) |
| **358988** | 52/118 | USA (99%), Mexico (1%) | North America (100%) | 2021-03-24 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (99%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_K1191N (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),NSP2_G339S (100%),Spike_A570D (100%),NSP8_Q24R (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP2_E595K (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),NSP16_K160R (100%),Spike_S982A (100%),N_S235F (100%),NS8_R52I (99%) |
| **360480** | 53/105 | Netherlands (96%), Belgium (4%) | Europe (100%) | 2021-03-16 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (96%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),NSP5_K90R (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_Y144del (97%),NSP1_Q44R (78%),Spike_K147N (71%) |
| **363797** | 87/164 | Switzerland (63%), Germany (12%), Lithuania (7%), United Kingdom (7%), Denmark (4%) | Europe (99%) | 2020-12-26 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_T307I (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204P (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS8_K68stop (80%),NSP14_T122A (64%),NSP4_D50A (64%) |
| **365237** | 92/270 | United Kingdom (100%), Norway (0%) | Europe (100%) | 2021-03-30 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | NS7a_L116F (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NSP2_P129L (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_H1274Y (100%),NS7a_V82A (100%),Spike_F157del (100%),Spike_T19R (100%),NS7a_T120I (100%),N_R385K (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),Spike_D950N (100%),NSP3_P822L (100%),NSP16_S248I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),NSP15_H234Y (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%) |
| **371575** | 81/99 | India (32%), USA (26%), Switzerland (10%), Germany (8%), Belgium (6%) | Asia (41%) | 2021-03-04 to 2021-06-07 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NS7a_V82A (100%),Spike_F157del (100%),NS7a_T120I (100%),N_R385K (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),NSP3_P822L (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),NSP15_H234Y (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),NSP2_P129L (99%),Spike_T19R (99%),NS7a_L116F (98%),N_D63G (97%),Spike_D950N (95%),NSP3_H1274Y (84%) |
| **376081** | 460/1189 | United Kingdom (82%), USA (9%), India (4%), Canada (1%), Singapore (1%) | Europe (83%) | 2021-01-12 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),NSP3_P1228L (100%),NSP3_A488S (100%),NSP4_T492I (100%),NSP14_A394V (100%),N_D377Y (100%),NS7b_T40I (100%),Spike_T478K (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),Spike_R158del (100%),Spike_F157del (100%),M_I82T (100%),Spike_D950N (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),NSP6_T77A (100%),NSP12_P323L (100%),N_G215C (100%),Spike_T19R (100%),NS7a_T120I (100%),NS7a_V82A (100%),Spike_G142D (98%) |
| **380464** | 60/190 | United Kingdom (97%), Slovakia (1%), Sweden (1%), Estonia (1%), Japan (1%) | Europe (99%) | 2021-01-15 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NS7a_E95stop (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP13_S74L (90%),NSP4_A446V (90%),NSP3_P153L (90%) |
| **380622** | 516/1349 | United Kingdom (90%), USA (4%), India (2%), Japan (1%), Sweden (1%) | Europe (92%) | 2021-03-08 to 2021-06-11 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | M_I82T (100%),N_D63G (100%),N_R203M (100%),NS3_S26L (100%),Spike_T478K (100%),Spike_D614G (100%),NS7a_V82A (100%),N_D377Y (100%),Spike_P681R (100%),NSP12_P323L (100%),Spike_L452R (100%),NS7a_T120I (100%),NSP3_P822L (100%),NSP12_G671S (100%),NSP13_P77L (100%),NSP4_A446V (100%),Spike_R158del (100%),Spike_F157del (100%),Spike_E156G (100%),NSP6_V149A (100%),Spike_T19R (100%),Spike_D950N (100%),NSP6_T181I (100%),Spike_A222V (99%),Spike_G142D (97%) |
| **387085** | 381/598 | United Kingdom (37%), India (21%), Singapore (11%), Vietnam (8%), USA (6%) | Europe (46%) | 2021-03-09 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_R203M (100%),NSP12_G671S (100%),Spike_P681R (100%),Spike_R158del (100%),Spike_F157del (100%),M_I82T (100%),NSP6_V149A (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),Spike_T478K (100%),Spike_D614G (100%),Spike_L452R (100%),NSP6_T181I (100%),NS3_S26L (100%),Spike_A222V (100%),N_D377Y (100%),N_D63G (100%),Spike_T19R (100%),NSP3_P822L (100%),NS7a_T120I (99%),NS7a_V82A (99%),Spike_D950N (99%),NSP12_P323L (99%),Spike_G142D (92%) |
| **388915** | 430/765 | United Kingdom (57%), India (21%), USA (10%), Canada (3%), Japan (2%) | Europe (61%) | 2021-01-07 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_R203M (100%),NSP12_G671S (100%),Spike_P681R (100%),NS7a_V82A (100%),M_I82T (100%),NSP6_V149A (100%),NSP13_P77L (100%),Spike_T478K (100%),Spike_D614G (100%),Spike_L452R (100%),N_D63G (100%),NS7a_T120I (100%),NSP4_A446V (100%),NS3_S26L (100%),Spike_T19R (100%),N_D377Y (100%),NSP3_P822L (100%),NSP12_P323L (99%),NS7a_L116F (99%),NSP2_P129L (99%),Spike_D950N (99%),NSP14_P46L (98%),Spike_R158del (96%),Spike_F157del (96%),Spike_E156G (96%),Spike_G142D (92%) |
| **395705** | 238/319 | United Kingdom (37%), India (13%), USA (12%), Japan (8%), France (5%) | Europe (56%) | 2021-03-21 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_R203M (100%),NSP12_G671S (100%),NSP2_P129L (100%),NS3_S26L (100%),Spike_P681R (100%),NS7a_V82A (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),NSP3_P822L (100%),NSP13_P77L (100%),NSP4_A446V (100%),Spike_T478K (100%),NSP15_H234Y (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),NS7a_L116F (100%),N_D63G (100%),Spike_T19R (100%),NS7a_T120I (100%),N_R385K (100%),NSP3_H1274Y (99%),Spike_R158del (99%),Spike_F157del (99%),Spike_E156G (99%),Spike_D950N (97%),Spike_G142D (87%) |
| **398218** | 30/121 | United Kingdom (100%) | Europe (100%) | 2021-04-01 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP5_N274S (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),NSP16_R216N (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP4_L323F (99%),NS8_V32A (99%),NS7a_P84S (98%) |
| **408651** | 32/52 | USA (54%), Germany (35%), United Kingdom (4%), Sweden (4%), France (2%) | North America (54%) | 2020-12-04 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NS7a_T14I (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (98%),NSP12_P227L (85%) |
| **414825** | 26/56 | United Kingdom (100%) | Europe (100%) | 2021-04-14 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NSP6_T181I (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NS7a_V82A (100%),Spike_F157del (100%),Spike_T19R (100%),NS7a_T120I (100%),Spike_A222V (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),Spike_D950N (100%),NSP3_P822L (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),NSP3_T64I (96%),NSP13_I304M (89%) |
| **414828** | 265/986 | United Kingdom (100%) | Europe (100%) | 2021-04-14 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NS7a_T120I (100%),NSP3_P1469S (100%) |
| **414920** | 30/84 | United Kingdom (98%), France (2%) | Europe (100%) | 2021-03-28 to 2021-06-09 | **Active** | AV.1 (100%) | GR (100%) | Alert | Spike_T95I (100%),NSP2_A411V (100%),NSP6_S106del (100%),Spike_E484K (100%),N_R203K (100%),NSP2_G339S (100%),Spike_G142D (100%),Spike_I1130V (100%),NSP3_H342Y (100%),Spike_D80G (100%),M_H125Y (100%),NSP12_S434A (100%),Spike_P681H (100%),Spike_Y144del (100%),N_I157V (100%),NSP3_P822L (100%),NSP14_A119V (100%),NSP6_G107del (100%),Spike_N439K (100%),NSP3_N1587S (100%),NSP6_F108del (100%),NSP4_A446V (100%),N_G204R (100%),M_A63T (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_D1139H (98%),NSP13_T481M (95%),NSP1_D75G (95%),NSP3_K927I (95%),NS3_V256I (94%) |
| **415619** | 32/40 | USA (32%), France (30%), United Kingdom (18%), Germany (5%), Poland (5%) | Europe (65%) | 2021-01-07 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NS8_K68stop (95%) |
| **419471** | 119/265 | United Kingdom (82%), USA (10%), Canada (5%), India (1%), Germany (1%) | Europe (83%) | 2021-04-13 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_R203M (100%),NSP12_G671S (100%),NSP6_T181I (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),Spike_F157del (100%),Spike_T19R (100%),Spike_A222V (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),Spike_D950N (100%),NSP3_P822L (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),N_D63G (100%),NS7a_V82A (100%),Spike_G142D (98%),NS7a_T120I (97%),NSP4_M324I (86%),NSP9_T24I (85%),NSP4_M33V (85%) |
| **422368** | 60/241 | United Kingdom (100%) | Europe (100%) | 2021-03-12 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP3_K1715R (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),NSP4_S34F (90%) |
| **423255** | 202/343 | United Kingdom (43%), USA (10%), Portugal (8%), Japan (7%), Switzerland (6%) | Europe (74%) | 2021-03-30 to 2021-06-10 | **Active** | B.1.617.2 (85%) | G (99%) | Delta | N_G215C (100%),N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),NSP3_P1228L (100%),NSP3_A488S (100%),NSP4_T492I (100%),Spike_T19R (100%),NS7a_T120I (100%),M_I82T (100%),NS7b_T40I (100%),NSP13_P77L (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_R158del (100%),NS7a_V82A (100%),Spike_F157del (100%),Spike_D950N (100%),Spike_E156G (100%),Spike_L452R (100%),NSP14_A394V (99%),N_D377Y (99%),N_D63G (94%),Spike_T95I (72%),Spike_G142D (70%) |
| **423259** | 80/174 | United Kingdom (58%), Russia (33%), USA (7%), Japan (1%), Switzerland (1%) | Europe (93%) | 2021-04-16 to 2021-06-08 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),NSP2_K81N (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NS7a_P45L (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),Spike_G142D (97%),NSP3_A579V (66%) |
| **427161** | 3286/10089 | United Kingdom (98%), USA (1%), Japan (0%), France (0%), Germany (0%) | Europe (99%) | 2021-04-01 to 2021-06-11 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_R203M (100%),NSP12_G671S (100%),N_D377Y (100%),M_I82T (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_L452R (100%),N_G215C (100%),NS3_S26L (100%),NSP3_P1228L (100%),NSP4_T492I (100%),NSP14_A394V (100%),NS7b_T40I (100%),NSP6_T77A (100%),Spike_D614G (100%),Spike_R158del (100%),NSP3_A488S (100%),Spike_F157del (100%),Spike_E156G (100%),NSP4_V167L (100%),Spike_P681R (100%),Spike_T19R (100%),N_D63G (100%),NS7a_V82A (100%),NS7a_T120I (100%),NSP3_P1469S (100%),Spike_D950N (100%),NSP13_P77L (100%),Spike_G142D (100%),Spike_T95I (99%),NSP3_A1711V (96%) |
| **427290** | 478/2910 | United Kingdom (100%), Sweden (0%), Iran (0%), USA (0%), Norway (0%) | Europe (100%) | 2021-04-06 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),Spike_T95I (100%),Spike_G142D (100%),Spike_T19R (100%),NSP13_P77L (100%),NS7a_T120I (100%),NS3_S26L (100%),NS7a_V82A (100%),NSP3_A1711V (100%) |
| **428649** | 37/87 | United Kingdom (70%), Italy (9%), USA (7%), Switzerland (6%), Netherlands (2%) | Europe (92%) | 2021-03-15 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **428951** | 72/126 | United Kingdom (48%), Italy (13%), USA (10%), Norway (10%), Japan (5%) | Europe (79%) | 2021-03-23 to 2021-06-09 | **Active** | B.1.617.2 (99%) | G (100%) | Delta | N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS3_D238Y (100%),NS7a_T120I (100%),NSP2_K81N (100%),N_D377Y (100%),M_I82T (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),N_G215C (99%),Spike_D950N (98%),Spike_G142D (90%) |
| **433414** | 99/374 | United Kingdom (97%), Spain (2%), Portugal (1%), France (0%), USA (0%) | Europe (100%) | 2021-04-20 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),N_S327L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NS3_S26L (100%),Spike_G142D (98%) |
| **433609** | 24/112 | United Kingdom (100%) | Europe (100%) | 2021-03-23 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),E_V58F (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP3_P1921S (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),NS8_S21N (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),NSP2_K454R (100%),NS7a_H47Y (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP6_V179I (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **433766** | 31/118 | United Kingdom (100%) | Europe (100%) | 2021-04-06 to 2021-06-09 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),NSP3_Q203H (100%),Spike_P681H (100%),NSP3_H1274Y (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NSP3_T656I (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **435762** | 38/47 | Brazil (87%), Portugal (6%), United Kingdom (4%), USA (2%) | South America (87%) | 2021-03-02 to 2021-06-08 | **Active** | P.1 (98%) | GR (100%) | Gamma | Spike_R190S (100%),NSP6_S106del (100%),Spike_H655Y (100%),Spike_E484K (100%),N_R203K (100%),Spike_K417T (100%),Spike_T1027I (100%),Spike_N501Y (100%),NS3_S253P (100%),NSP6_L75F (100%),Spike_L18F (100%),N_P80R (100%),Spike_T20N (100%),NSP3_K977Q (100%),NSP6_G107del (100%),NSP6_F108del (100%),NSP3_S370L (100%),N_G204R (100%),NS8_E92K (100%),Spike_P26S (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_V1176F (100%),E_P71S (100%),NSP13_E341D (100%),Spike_D138Y (94%) |
| **437233** | 64/193 | United Kingdom (100%) | Europe (100%) | 2021-01-12 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP3_V477F (100%),NSP13_K460R (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NS3_S92P (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),NSP3_A465V (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%),Spike_V70del (99%) |
| **437275** | 47/204 | United Kingdom (100%), Japan (0%) | Europe (100%) | 2021-04-19 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NSP6_T181I (100%),NS3_S26L (100%),Spike_P681R (100%),N_G18C (100%),Spike_R158del (100%),NSP3_L1244F (100%),NS7a_V82A (100%),Spike_F157del (100%),Spike_T19R (100%),NS7a_T120I (100%),Spike_A222V (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),Spike_D950N (100%),NSP3_P822L (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),NSP14_T219N (100%),NSP13_H464Y (100%),NSP10_H48Y (99%) |
| **439896** | 72/198 | Slovenia (41%), Spain (33%), United Kingdom (11%), USA (5%), Sweden (3%) | Europe (95%) | 2021-01-26 to 2021-06-08 | **Active** | B.1.1.7 (100%) | GRY (98%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **449110** | 177/647 | United Kingdom (100%) | Europe (100%) | 2021-04-25 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),Spike_G1124V (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),Spike_L216F (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **454986** | 42/133 | United Kingdom (100%) | Europe (100%) | 2021-04-27 to 2021-06-07 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **458158** | 58/98 | Russia (68%), USA (16%), Italy (5%), United Kingdom (4%), Czech Republic (2%) | Europe (83%) | 2021-04-22 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),NSP2_K81N (100%),N_D377Y (100%),M_I82T (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NS7a_P45L (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),Spike_G142D (98%),Spike_D950N (95%) |
| **458750** | 127/513 | United Kingdom (99%), Denmark (1%), USA (0%) | Europe (100%) | 2021-04-19 to 2021-06-10 | **Active** | B.1.617.2 (99%) | G (100%) | Delta | Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),NSP3_S1230F (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),N_G215C (100%) |
| **459521** | 45/158 | United Kingdom (100%) | Europe (100%) | 2021-04-28 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **467245** | 51/295 | United Kingdom (98%), Italy (2%) | Europe (100%) | 2021-05-01 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NSP3_A1711V (98%) |
| **467294** | 103/317 | United Kingdom (100%) | Europe (100%) | 2021-05-01 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NSP9_Q11H (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),NS7a_C58F (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NS7a_A79D (100%) |
| **467353** | 53/143 | United Kingdom (100%) | Europe (100%) | 2021-05-01 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **474290** | 23/67 | United Kingdom (100%) | Europe (100%) | 2021-05-04 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NS3_S26L (99%) |
| **474310** | 96/354 | United Kingdom (100%) | Europe (100%) | 2021-05-03 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **477389** | 66/190 | United Kingdom (100%) | Europe (100%) | 2021-05-03 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | NSP14_R163C (100%),N_D63G (100%),NSP12_G671S (100%),Spike_G142D (100%),NSP6_T181I (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_A256V (100%),M_A2S (100%),NS7a_V82A (100%),Spike_F157del (100%),Spike_T19R (100%),NS7a_T120I (100%),Spike_A222V (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),Spike_D950N (100%),NSP3_P822L (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),N_R203M (99%) |
| **480083** | 28/84 | United Kingdom (100%) | Europe (100%) | 2021-04-27 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | NS7a_L116F (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NSP2_P129L (100%),NS3_S26L (100%),NSP12_I244V (100%),NSP14_P46L (100%),Spike_P681R (100%),Spike_R158del (100%),NS7a_V82A (100%),Spike_F157del (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),NSP6_V149A (100%),Spike_D950N (100%),NSP3_P822L (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP4_A446V (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%) |
| **480491** | 48/61 | USA (72%), India (10%), Netherlands (5%), Aruba (3%), Australia (3%) | North America (72%) | 2021-03-29 to 2021-06-08 | **Active** | B.1.617.2 (98%) | G (100%) | Delta | NSP4_D217N (100%),N_R203M (100%),NSP2_P129L (100%),NS3_S26L (100%),NSP4_F375S (100%),Spike_P681R (100%),NS7a_V82A (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),NSP3_P822L (100%),NSP15_K259R (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_R158del (98%),Spike_F157del (98%),Spike_E156G (98%),Spike_T478K (98%),Spike_L452R (98%),N_D63G (95%),Spike_T19R (95%),Spike_D950N (95%),NSP6_H11Q (93%),Spike_K77T (85%) |
| **481750** | 51/232 | Singapore (79%), United Kingdom (21%) | Asia (79%) | 2021-05-06 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NSP2_T223I (100%),N_G214del (100%),NSP5_V296I (100%),N_G215del (100%) |
| **482194** | 29/34 | France (26%), Bulgaria (18%), Netherlands (15%), United Kingdom (12%), Belgium (12%) | Europe (88%) | 2020-12-20 to 2021-06-07 | **Active** | B.1.1.7 (100%) | GRY (97%) | Alpha | Spike_H69del (100%),NS8_Q27stop (100%),NSP3_T183I (100%),Spike_T716I (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_G1219V (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_S982A (100%),N_S235F (100%),Spike_Y144del (97%),N_D3L (97%) |
| **483388** | 35/52 | USA (100%) | North America (100%) | 2021-03-20 to 2021-06-07 | **Active** | B.1.526 (67%) | GH (98%) | Iota | Spike_T95I (100%),NS7a_L116F (100%),Spike_L5F (100%),N_P13L (100%),NSP4_L438P (100%),Spike_D253G (100%),NSP3_G1128S (100%),Spike_S477N (100%),NS3_P42L (100%),N_S202R (100%),NSP13_Q88H (100%),NS3_Q57H (100%),NS8_T11I (100%),NSP2_T85I (100%),Spike_Q957R (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP6_S106del (98%),NSP6_G107del (98%),NSP6_F108del (98%),NSP14_T31I (98%) |
| **487382** | 38/107 | United Kingdom (100%) | Europe (100%) | 2021-05-10 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),NS8_S67F (100%),Spike_T478K (100%),NSP14_A85S (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **490975** | 23/61 | United Kingdom (100%) | Europe (100%) | 2021-05-11 to 2021-06-10 | **Active** | B.1.1.7 (100%) | GRY (100%) | Alpha | NSP2_N280Y (100%),Spike_H69del (100%),NS8_Q27stop (100%),NS8_L118V (100%),NSP3_T183I (100%),Spike_T716I (100%),NS8_K68stop (100%),NSP6_S106del (100%),N_R203K (100%),Spike_A570D (100%),NSP12_A185V (100%),NSP13_P402S (100%),NS8_I71T (100%),NSP13_A296S (100%),Spike_N501Y (100%),NSP3_I1412T (100%),NS8_R52I (100%),Spike_P681H (100%),Spike_Y144del (100%),Spike_Q14H (100%),Spike_Y449S (100%),NSP6_G107del (100%),NSP3_A890D (100%),Spike_D1118H (100%),NSP6_F108del (100%),NS8_Y73C (100%),N_G204R (100%),Spike_V70del (100%),NSP15_V22L (100%),NSP12_P323L (100%),Spike_D614G (100%),N_D3L (100%),Spike_S982A (100%),N_S235F (100%) |
| **493662** | 34/267 | United Kingdom (100%) | Europe (100%) | 2021-05-10 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NSP13_M576I (100%),NS7a_V82A (100%),NS7a_T120I (100%),Spike_T95I (100%),Spike_G142D (100%) |
| **497360** | 79/282 | United Kingdom (100%) | Europe (100%) | 2021-05-14 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),NS7a_I88T (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **499704** | 55/90 | Thailand (64%), Cambodia (7%), USA (6%), Belgium (6%), Spain (6%) | Asia (73%) | 2021-04-04 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_R203M (100%),NSP12_G671S (100%),NSP2_P129L (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_T19R (100%),N_R385K (100%),N_D377Y (100%),M_I82T (100%),N_L139F (100%),NSP6_V149A (100%),Spike_D950N (100%),NSP3_P822L (100%),NSP13_P77L (100%),NSP4_A446V (100%),NSP15_H234Y (100%),Spike_T478K (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),NS7a_L116F (99%),NS7a_V82A (99%),NS7a_T120I (99%),NSP3_H1274Y (96%),N_D63G (93%),Spike_R158del (90%),Spike_F157del (90%),Spike_E156G (90%) |
| **503807** | 32/98 | United Kingdom (100%) | Europe (100%) | 2021-05-18 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP8_T187I (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),NSP2_T429I (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NS7a_A55S (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),NSP13_T307I (98%) |
| **504218** | 24/137 | United Kingdom (100%) | Europe (100%) | 2021-05-18 to 2021-06-09 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%) |
| **515416** | 36/112 | United Kingdom (100%) | Europe (100%) | 2021-05-26 to 2021-06-10 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),NSP3_A1711V (100%),Spike_T95I (100%),N_D63G (100%),NSP12_G671S (100%),Spike_G142D (100%),NS3_S26L (100%),Spike_P681R (100%),Spike_R158del (100%),NSP3_P1228L (100%),NS3_K235T (100%),NS7a_V82A (100%),NSP3_A488S (100%),Spike_F157del (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NS7b_T40I (100%),NSP13_P77L (100%),Spike_E156G (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),NSP4_V167L (100%),Spike_L452R (100%),N_R203M (99%) |
| **520601** | 50/55 | France (89%), Switzerland (7%), Spain (2%), Luxembourg (2%) | Europe (100%) | 2021-02-27 to 2021-06-08 | **Active** | B.1.351 (100%) | GH (100%) | Beta | Spike_D215G (100%),E_P71L (100%),NSP3_K837N (100%),Spike_E484K (100%),N_T205I (100%),NS3_Q57H (100%),Spike_A701V (100%),NSP2_T85I (100%),Spike_D80A (100%),Spike_N501Y (100%),N_Q28R (100%),NSP12_P323L (100%),NSP5_K90R (100%),Spike_D614G (100%),NS3_S171L (100%),Spike_K417N (98%),Spike_L242del (91%),Spike_L244del (87%),Spike_A243del (87%),NSP6_G107del (84%),NSP6_S106del (84%),NSP6_F108del (84%) |
| **522987** | 41/61 | Spain (43%), USA (13%), Belgium (13%), Portugal (11%), India (7%) | Europe (74%) | 2021-04-04 to 2021-06-08 | **Active** | B.1.617.2 (100%) | G (100%) | Delta | N_G215C (100%),N_D63G (100%),N_R203M (100%),NSP12_G671S (100%),NS3_S26L (100%),Spike_P681R (100%),NSP3_P1228L (100%),NS7a_V82A (100%),NSP3_A488S (100%),NSP4_T492I (100%),NSP14_A394V (100%),Spike_T19R (100%),NS7a_T120I (100%),N_D377Y (100%),M_I82T (100%),Spike_D950N (100%),NSP13_P77L (100%),NSP3_P1469S (100%),Spike_T478K (100%),NSP6_T77A (100%),NSP12_P323L (100%),Spike_D614G (100%),Spike_L452R (100%),Spike_T95I (98%),Spike_R158del (98%),Spike_F157del (98%),NS7b_T40I (98%),Spike_E156G (98%),NSP4_V167L (98%) |
